<ul class="dastart">
  {% for interview in interview_info %}
  <li><a href="{{ interview['link'] }}"{% if interview['status_class'] %} class="{{ interview['status_class'] }}"{% endif %}>{{ interview['title'] }}</a>{% if interview['subtitle'] %} <span class="{% if interview['subtitle_class'] %}{{ interview['subtitle_class'] }}{% else %}text-muted dasubtitle{% endif %}"></span>{% endif %}</li>
  {% endfor %}
</ul>
