{%- set footer_content = get_part('global footer') %}
{% extends 'flask_user/public_base.html' %}

{% block content %}
{% from "base_templates/form_macros.html" import render_submit_field, render_field %}
<h1>{{ title }}</h1>

<p>{{ description }}</p>

<form action="" method="POST" role="form" class="form">
  {{ form.hidden_tag() }}
  <div class="form-group">
    {{ render_field(form.phone_number) }}
  </div>
  <div class="form-actions">
    {{ render_submit_field(form.submit) }}
  </div>
</form>

{% endblock %}
