{%- set footer_content = get_part('forgot password page footer', get_part('global footer')) %}
{%- set page_title = get_part('forgot password page title', word('Forgot password')) %}
{%- set tab_title = get_part('forgot password page tab title', word('Forgot password')) %}
{%- set extra_css = get_part('forgot password page extra css') %}
{%- set extra_js = get_part('forgot password page extra javascript') %}
{%- extends 'flask_user/public_base.html' %}
{%- block content %}
{%- from "base_templates/form_macros.html" import render_field, render_submit_field %}
          <h1>{{ get_part('forgot password page heading', word('Forgot password')) }}</h1>
{{ get_part('forgot password page pre') }}
          <form action="" method="POST" class="form" role="form">
            {{ form.hidden_tag() }}
            {{ render_field(form.email) }}
            {{ get_part('forgot password page submit') }}<div class="form-actions">
              {{ render_submit_field(form.submit) }}
            </div>
          </form>{{ get_part('forgot password page post') }}
{%- endblock %}
