{% extends 'base_templates/page_base_half.html' %}

{% block content %}

<h1>Packages</h1>

<h3><a href="{{ url_for('create_package') }}">Create a template package</a></h3>

Download a zip file containing an empty template for a package.

<h3><a href="{{ url_for('create_playground_package') }}">Create a package from Playground files</a></h3>

Download a zip file containing a package that you <a href="{{ url_for('playground_packages') }}">defined in the Playground</a>.

<h3><a href="{{ url_for('update_package') }}">Update a package</a></h3>

Upload a zip file containing a package, pull from a Github repository for a package, pull a package from PyPI, upgrade a specific package, or upgrade docassemble.

{% endblock %}
