{%- extends "base_templates/base.html" %}
{%- block main %}
      <div class="row">
        <div class="col-md-7 col-lg-6">
          {%- block content %}{% endblock %}
        </div>
      </div>
{%- endblock %}
