{%- set footer_content = get_part('global footer') %}
{% extends 'flask_user/public_base.html' %}

{% block content %}
{% from "flask_user/_macros.html" import render_field, render_submit_field %}
<h1>{{ word("Send Confirmation E-mail") }}</h1>

<form action="" method="POST" class="form" role="form">
    {{ form.hidden_tag() }}
    {{ render_field(form.email) }}
    {{ render_submit_field(form.submit) }}
</form>

{% endblock %}
